@@ -3,14 +3,7 @@
 
 """
 U{Python Commons<http://assorted.sf.net/python-commons>} is a
-collection of general-purpose utilities released under the U{PSF
-license<http://www.python.org/psf/license.html>}.
-
-You can download the latest releases
-U{here<http://assorted.sf.net/python-commons/download>}. To install,
-run setup.py or setup.bash. setup.bash requires
-U{simple-setup<http://assorted.sf.net/shell-tools/simple-setup>} which
-is part of U{shell-tools<http://assorted.sf.net/shell-tools>}.
+general-purpose library.
 
 @author: Yang Zhang
 @copyright: Yang Zhang unless otherwise noted
