@@ -14,7 +14,7 @@ from L{invalid_filename_chars}.
 from __future__ import with_statement
 
 import os, re, tempfile
-
+from cPickle import *
 from path import path
 
 def soft_makedirs( path ):
@@ -113,3 +113,62 @@ class disk_double_buffer( object ):
     def close( self ):
         self.reader.close()
         self.writer.close()
+
+def versioned_guard(path, fresh_version):
+    """
+    Maintain a version object.  This is useful for working with versioned
+    caches.
+
+    @param path: The path to the file containing the cached version object.
+    @type path: str
+
+    @param fresh_version: The actual latest version that the cached version
+    should be compared against.
+    @type fresh_version: object (any type that can be compared)
+
+    @return: True iff the cached version is obsolete (less than the fresh
+    version or doesn't exist).
+    @rtype: bool
+    """
+    cache_version = None
+    try:
+        with file( path ) as f: cache_version = load(f)
+    except IOError, (errno, errstr):
+        if errno != 2: raise
+    print cache_version, fresh_version
+    if cache_version is None or fresh_version > cache_version:
+        with file( path, 'w' ) as f: dump(fresh_version, f)
+        return True
+    else:
+        return False
+
+def versioned_cache(version_path, fresh_version, cache_path, cache_func):
+    """
+    If fresh_version is newer than the version in version_path, then invoke
+    cache_func and cache the result in cache_path (using pickle).
+
+    Note the design flaw with L{versioned_guard}: the updated version value is
+    stored immediately, rather than after updating the cache.
+
+    @param version_path: The path to the file version.
+    @type version_path: str
+
+    @param fresh_version: The actual, up-to-date version value.
+    @type fresh_version: object (any type that can be compared)
+
+    @param cache_path: The path to the cached data.
+    @type cache_path: str
+
+    @param cache_func: The function that produces the fresh data to be cached.
+    @type cache_func: function (no arguments)
+    """
+    if versioned_guard( version_path, fresh_version ):
+        # cache obsolete, force-fetch new data
+        print 'here'
+        result = cache_func()
+        with file(cache_path, 'w') as f: dump(result, f)
+        return result
+    else:
+        # cache up-to-date (should be available since dlcs-timestamp exists!)
+        print 'there'
+        with file(cache_path) as f: return load(f)
